@@ -26,7 +26,7 @@ def flatpage(request):
         row = rows[0]
         
         
-        return render_to_response(row.doc.get('template', 'static.html'), {'doc': row.doc}, RequestContext(request))
+        return render_to_response(row.doc.get('template', 'static.html'), {'doc': row.doc}, RequestContext(request), mimetype=row.doc.get('content_type', 'text/html'))
     else:
         raise Http404('Page not found')
     
